$(document).ready(function(){
    // Initialize carousel
    $('.carousel').slick({
        arrows: false,
        autoplay: true,
        dots: true,
        appendDots: '.carousel',
        dotsClass: 'slick-dots -mt-10 mx-auto',
        autoplaySpeed: 2500
    });

    // Set element text when file is selected
    let element = document.querySelector( '#photo' )
    if(element) {
        element.addEventListener('change', e => {
            let fileName = e.target.value.split('\\').pop();

            const reader = new FileReader();

            reader.addEventListener("load", function () {
                // convert image file to base64 string
                $('input[name="photo"]').val(reader.result)
            }, false);

            if (element.files && element.files[0]) {
                if(element.files[0].size > 5000000) {
                    alert('File is too large.')
                    return
                }

                let types = ['jpg', 'jpeg', 'jpe', 'jif', 'jfif', 'jfi', 'png', 'bmp', 'gif', 'svg']
                if(!types.includes(element.files[0].type.split('/')[1])) {
                    alert(`File must be of type ${types.join(', ')}`)
                    return
                }

                reader.readAsDataURL(element.files[0]);
            }

            if (fileName)
                document.querySelector('#photo').parentElement.children[1].innerHTML = fileName;
        });
    }

    $('form').submit(function(e){
        e.preventDefault();

        $('#errors').addClass('hidden')
        $('#errors .error').remove()

        $(e.target).find(':submit').attr('disabled', true)
        $(e.target).find(':submit .spinner').toggleClass('hidden')
        $(e.target).find(':submit .text').addClass('invisible')

        $.ajax({
            url: $(e.target).attr('action'),
            type: $(e.target).attr('method'),
            dataType: 'json',
            data: JSON.stringify($(e.target).serializeArray()),
            success: function(resp) {
                if(resp.success) {
                    window.location = '/quotes/thankyou'
                }


                if(resp.errors && resp.errors.length > 0) {
                    $('#errors').removeClass('hidden')
                    for (let e of resp.errors)
                        $('#errors').append(`<p class="ml-2 error">${e.param} ${e.msg}</p>`)
                    $('#errors').append('<hr class="error">')
                }
            },
            error: function (err) {
                console.log(err)
                $('#errors').removeClass('hidden')
                $('#errors .error').remove()
                if(err.responseJSON && err.responseJSON.message)
                    $('#errors').append(`<p class="ml-2 error">${err.responseJSON.message}</p>`)
                else
                    $('#errors').append(`<p class="ml-2 error">An unknown error has occurred, please try again.</p>`)
                $('#errors').append('<hr class="error">')

                $(e.target).find(':submit').attr('disabled', false)
                $(e.target).find(':submit .spinner').toggleClass('hidden')
                $(e.target).find(':submit .text').removeClass('invisible')
            }
        });
    });

    //set a custom validation message on patternMismatch
    $('[validation-message]').each(function() {
        $(this).on('input', function (event) {
            if(this.validity.patternMismatch)
                this.setCustomValidity($(this).attr('patternMismatch-error'))
            else
                this.setCustomValidity('')
        })
    })
});

